@@ -32,7 +32,7 @@ class HSResult:
         return self
 
 
-def line(number):
+def line(number = None,message = None):
     if number == None:
         number = 0
     print("\n\n<%s> ----------------------"
@@ -40,3 +40,6 @@ def line(number):
           "---------------------------"
           "---------------------------"
           "------------"%(number))
+    if message != None:
+        print('    ' + message)
+        print("    ----------------" )
